oceanum.datamesh.Catalog
========================

.. currentmodule:: oceanum.datamesh

.. autoclass:: Catalog

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Catalog.ids
   
   

   
   
   .. rubric:: Methods
   
   .. automethod:: __init__
   .. automethod:: keys
   .. automethod:: load
   .. automethod:: load_async
   .. automethod:: query
   .. automethod:: query_async
   
   